@@ -5,12 +5,12 @@
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.42.1")
+(defparameter *autoconf-version* "5.42.2")
 (defparameter *autoconf-libdir* "/usr/lib")
 (defparameter *autoconf-libexecdir* "/usr/lib")
 (defparameter *autoconf-datadir* "/usr/share")
 (defparameter *autoconf-infodir* "/usr/share/info")
-(defparameter *autoconf-host* "armv6l-unknown-linux-gnueabi")
+(defparameter *autoconf-host* "armv6l-unknown-linux-gnueabihf")
 ;; This variable is kept for backwards compatibiliy reasons:
 ;; We seem to be in the fortunate position that we sometimes need to check for windows.
 ;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
@@ -21,5 +21,5 @@
 ;; This will be T if this was a lisp-only build
 (defparameter *autoconf-lisp-only-build* (eq t '@lisp_only_build@))
  
-(defparameter *maxima-source-root* "/build/maxima-ecl/src/maxima-5.42.1")
+(defparameter *maxima-source-root* "/build/maxima-ecl/src/maxima-5.42.2")
 (defparameter *maxima-default-layout-autotools* "true")
